==> robomaker-0.26.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnFleetProps.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * Properties for defining a `AWS::RoboMaker::Fleet`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:56:16.699Z")
public interface CfnFleetProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::RoboMaker::Fleet.Name`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-name
     */
    java.lang.String getName();
    /**
     * `AWS::RoboMaker::Fleet.Name`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-name
     */
    void setName(final java.lang.String value);
    /**
     * `AWS::RoboMaker::Fleet.Tags`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-tags
     */
    com.fasterxml.jackson.databind.node.ObjectNode getTags();
    /**
     * `AWS::RoboMaker::Fleet.Tags`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-tags
     */
    void setTags(final com.fasterxml.jackson.databind.node.ObjectNode value);

    /**
     * @return a {@link Builder} of {@link CfnFleetProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnFleetProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.String _name;
        @javax.annotation.Nullable
        private com.fasterxml.jackson.databind.node.ObjectNode _tags;

        /**
         * Sets the value of Name
         * @param value `AWS::RoboMaker::Fleet.Name`
         * @return {@code this}
         */
        public Builder withName(@javax.annotation.Nullable final java.lang.String value) {
            this._name = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::RoboMaker::Fleet.Tags`
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnFleetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public CfnFleetProps build() {
            return new CfnFleetProps() {
                @javax.annotation.Nullable
                private java.lang.String $name = _name;
                @javax.annotation.Nullable
                private com.fasterxml.jackson.databind.node.ObjectNode $tags = _tags;

                @Override
                public java.lang.String getName() {
                    return this.$name;
                }

                @Override
                public void setName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$name = value;
                }

                @Override
                public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnFleetProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::RoboMaker::Fleet.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-name
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getName() {
            return this.jsiiGet("name", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Fleet.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-name
         */
        @Override
        public void setName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("name", value);
        }

        /**
         * `AWS::RoboMaker::Fleet.Tags`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-tags
         */
        @Override
        @javax.annotation.Nullable
        public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
            return this.jsiiGet("tags", com.fasterxml.jackson.databind.node.ObjectNode.class);
        }

        /**
         * `AWS::RoboMaker::Fleet.Tags`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> robomaker-0.27.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnFleetProps.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * Properties for defining a `AWS::RoboMaker::Fleet`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:34:14.447Z")
public interface CfnFleetProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::RoboMaker::Fleet.Name`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-name
     */
    java.lang.String getName();
    /**
     * `AWS::RoboMaker::Fleet.Tags`
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-tags
     */
    com.fasterxml.jackson.databind.node.ObjectNode getTags();

    /**
     * @return a {@link Builder} of {@link CfnFleetProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnFleetProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.String _name;
        @javax.annotation.Nullable
        private com.fasterxml.jackson.databind.node.ObjectNode _tags;

        /**
         * Sets the value of Name
         * @param value `AWS::RoboMaker::Fleet.Name`
         * @return {@code this}
         */
        public Builder withName(@javax.annotation.Nullable final java.lang.String value) {
            this._name = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::RoboMaker::Fleet.Tags`
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final com.fasterxml.jackson.databind.node.ObjectNode value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnFleetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public CfnFleetProps build() {
            return new CfnFleetProps() {
                @javax.annotation.Nullable
                private final java.lang.String $name = _name;
                @javax.annotation.Nullable
                private final com.fasterxml.jackson.databind.node.ObjectNode $tags = _tags;

                @Override
                public java.lang.String getName() {
                    return this.$name;
                }

                @Override
                public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("name", om.valueToTree(this.getName()));
                    obj.set("tags", om.valueToTree(this.getTags()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnFleetProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::RoboMaker::Fleet.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-name
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getName() {
            return this.jsiiGet("name", java.lang.String.class);
        }

        /**
         * `AWS::RoboMaker::Fleet.Tags`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-fleet.html#cfn-robomaker-fleet-tags
         */
        @Override
        @javax.annotation.Nullable
        public com.fasterxml.jackson.databind.node.ObjectNode getTags() {
            return this.jsiiGet("tags", com.fasterxml.jackson.databind.node.ObjectNode.class);
        }
    }
}
